function [xout,yout] = gluespec(x1,y1,x2,y2)
% Glue the spectra [x1,y1] and [x2,y2] together to one spectrum consisting
% of both.  All four arguments have to be vectors.
% In the overlap region the contributions of both spectra vary along
% a linear gradient.
% x-values of the overlap correspond to those of the left spectrum
% (right spectrum part is interpolated). 
	if min(x2) < min(x1)
		temp=x1;
		x1=x2;
		x2=temp;
		temp=y1;
		y1=y2;
		y2=temp;
	end
	%Now, min(x1) < min(x2)
	overlap = x1>min(x2);
	gradient = linspace(0,1,sum(overlap))';
	xout=[x1(x1<min(x2)); x1(overlap); x2(x2>max(x1))];
	yout=[y1(x1<min(x2));
		    (1-gradient).*y1(overlap) + (gradient).*interp1(x2,y2,x1(overlap));
    		y2(x2>max(x1))];
end

