% Ref   = Three known reference spectra dim(n x 3). Please sort by pH.
% pHRef = The pH values of the three reference spectra dim(1 x 3).
% Mix   = Array of m mixture spectra dim(n x m)
%
% pHMix = calculated pH values of the mixed spectra
%
% usage:
%       pHMix=phMix2(Ref, pHRef, Mix)

function pHMix=pHMix2(Ref, pHRef, Mix)
	options = optimset('MaxIter',100000,'MaxFunEvals',1e7,'TolX',1e-14,...
											'TolFun',1e-14);
	nSpec = size(Mix,2);
	pHMix = zeros(1, nSpec);

	%Fitte das mittlere Ref-Spektrum aus den beiden äußeren.
	refkoeff = fminsearch(@(x) sum((x(1)*Ref(:,1) + x(2)*Ref(:,3) ...
																					 - Ref(:,2)).^2), [0.5; 0.5]);

	aan=refkoeff(1);
	bbn=refkoeff(2);

	cHa=10^(-pHRef(1));
	cHn=10^(-pHRef(2));
	cHb=10^(-pHRef(3));

	for i=1:nSpec
		mixkoeff = fminsearch(@(x) sum((x(1)*Ref(:,1) + x(2)*Ref(:,3) ...
																				 - Mix(:,i)).^2), [.5;.5]);
		aa=mixkoeff(1);
		bb=mixkoeff(2);

		pHMix(i) = -1*log10((aa*bbn*cHa*cHb - aa*bbn*cHa*cHn ...
												 - aan*bb*cHa*cHb + aan*bb*cHb*cHn) ...
									 / (aa*bbn*cHb - aa*bbn*cHn - aan*bb*cHa + aan*bb*cHn));
	end
end












